@@ -1,7 +1,7 @@
 """
 amos: your python project companion
 Corey Rayburn Yung <coreyrayburnyung@gmail.com>
-Copyright 2021, Corey Rayburn Yung
+Copyright 2020-2022, Corey Rayburn Yung
 License: Apache-2.0
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,6 +16,7 @@ License: Apache-2.0
     See the License for the specific language governing permissions and
     limitations under the License.
     
+    
 ToDo:
    
 """
@@ -23,7 +24,7 @@ ToDo:
 """
 For Developers:
 
-As with all of my packages, I used Google-style docstrings and follow the Google 
+As with all of my packages, I use Google-style docstrings and follow the Google 
 Python Style Guide (https://google.github.io/styleguide/pyguide.html) with two 
 notable exceptions:
     1) I always add spaces around '='. This is because I find it more readable 
@@ -38,41 +39,26 @@ notable exceptions:
         at some point in the near future.
 
 My packages lean heavily toward over-documentation and verbosity. This is
-designed to make them more accessible to beginnning coders and generally usable.
-The one exception to that general rule is unit tests, which hopefully are clear 
-enough to not require further explanation. If there is any area of the 
+designed to make them more accessible to beginnning coders and generally more 
+usable. The one exception to that general rule is unit tests, which hopefully 
+are clear enough to not require further explanation. If there is any area of the 
 documentation that could be made clearer, please don't hesitate to email me or
 any other package maintainer - I want to ensure the package is as accessible and 
 useful as possible.
      
 """
-__version__ = '0.1.5'
+__version__ = '0.1.6'
 
 __package__ = 'amos'
 
 __author__ = 'Corey Rayburn Yung'
 
 
-from .base.bunches import *
-from .base.mappings import *
-from .base.sequences import *
-from .construct.configuration import *
-from .construct.factories import *
-from .construct.lazy import *
-from .core.check import *
-from .core.composites import *
-from .core.transform import *
-from .core.graph import *
-from .core.hybrid import *
-from .core.tree import *
-from .observe.examine import *
-from .observe.module import *
-from .observe.package import *
-from .observe.registries import *
-from .observe.traits import *
-from .repair.convert import *
-from .repair.modify import *
-from .repair.validate import *
-from .report.clock import *
-from .report.recap import *
-
+from base import *
+from convert import *
+from foundry import *
+from mapping import *
+from modify import *
+from registry import *
+from sequence import *
+from validate import *
